@@ -27,106 +27,122 @@
 constructPathways <- function(settings, andromeda) {
   andromeda$cohorts <- settings$cohorts %>%
     as.data.frame()
-  
+
   targetCohortIds <- getCohortIds(cohorts = settings$cohorts, cohortType = "target")
   eventCohortIds <- getCohortIds(cohorts = settings$cohorts, cohortType = "event")
   exitCohortIds <- getCohortIds(cohorts = settings$cohorts, cohortType = "exit")
 
-  selectPeople <- andromeda$cohortTable %>%
-    dplyr::filter(.data$cohortId == targetCohortIds) %>%
-    dplyr::distinct(.data$personId)
+  for (targetCohortId in targetCohortIds) {
+    targetCohortName <- andromeda$cohorts %>%
+      dplyr::filter(.data$cohortId == targetCohortId) %>%
+      dplyr::pull(.data$cohortName)
 
-  andromeda$currentCohorts <- andromeda$cohortTable %>%
-    dplyr::inner_join(selectPeople, by = dplyr::join_by("personId"))
+    message(sprintf(">> Starting on target: %s (%s)", targetCohortId, targetCohortName))
 
-  # Preprocess the target/event cohorts to create treatment history
-  createTreatmentHistory(
-    andromeda = andromeda,
-    targetCohortIds = targetCohortIds,
-    eventCohortIds = eventCohortIds,
-    exitCohortIds = exitCohortIds,
-    indexDateOffset = settings$indexDateOffset,
-    includeTreatments = settings$includeTreatments
-  )
+    selectPeople <- andromeda$cohortTable %>%
+      dplyr::filter(.data$cohortId == targetCohortId) %>%
+      dplyr::distinct(.data$personId)
   
-  n <- andromeda$attrition %>%
-    dplyr::collect() %>%
-    tail(1) %>%
-    dplyr::pull(.data$number_records)
-
-  if (n > 0) {
-    andromeda$exitHistory <- andromeda$treatmentHistory %>%
-      dplyr::filter(.data$type == "exit") %>%
-      dplyr::select(-"type")
-
-    andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
-      dplyr::filter(.data$type == "event")
-
-    doSplitEventCohorts(
+    andromeda$currentCohorts <- andromeda$cohortTable %>%
+      dplyr::inner_join(selectPeople, by = dplyr::join_by("personId"))
+  
+    # Preprocess the target/event cohorts to create treatment history
+    createTreatmentHistory(
       andromeda = andromeda,
-      splitEventCohorts = settings$splitEventCohorts,
-      splitTime = settings$splitTime
+      targetCohortId = targetCohortId,
+      eventCohortIds = eventCohortIds,
+      exitCohortIds = exitCohortIds,
+      indexDateOffset = settings$indexDateOffset,
+      includeTreatments = settings$includeTreatments
     )
 
-    doEraCollapse(
-      andromeda = andromeda,
-      eraCollapseSize = settings$eraCollapseSize
-    )
-
-    doCombinationWindow(
-      andromeda = andromeda,
-      combinationWindow = settings$combinationWindow,
-      minPostCombinationDuration = settings$minPostCombinationDuration
-    )
-
-    doFilterTreatments(
-      andromeda = andromeda,
-      filterTreatments = settings$filterTreatments
-    )
-
-    andromeda$exitHistory <- andromeda$exitHistory %>%
-      dplyr::mutate(eventCohortId = as.character(as.integer(.data$eventCohortId)))
-    
-    andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
-      dplyr::union_all(andromeda$exitHistory)
-
-    if (andromeda$treatmentHistory %>% dplyr::summarise(n = dplyr::n()) %>% pull() > 0) {
-      # Add eventSeq number to determine order of treatments in pathway
+    n <- andromeda$attrition %>%
+      dplyr::collect() %>%
+      tail(1) %>%
+      dplyr::pull(.data$number_records)
+  
+    if (n > 0) {
+      andromeda$exitHistory <- andromeda$treatmentHistory %>%
+        dplyr::filter(.data$type == "exit") %>%
+        dplyr::select(-"type")
+  
       andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
-        dplyr::arrange(.data$personId, .data$eventStartDate, .data$eventEndDate)
-
+        dplyr::filter(.data$type == "event")
+  
+      doSplitEventCohorts(
+        andromeda = andromeda,
+        splitEventCohorts = settings$splitEventCohorts,
+        splitTime = settings$splitTime
+      )
+  
+      doEraCollapse(
+        andromeda = andromeda,
+        eraCollapseSize = settings$eraCollapseSize
+      )
+  
+      doCombinationWindow(
+        andromeda = andromeda,
+        combinationWindow = settings$combinationWindow,
+        minPostCombinationDuration = settings$minPostCombinationDuration
+      )
+  
+      doFilterTreatments(
+        andromeda = andromeda,
+        filterTreatments = settings$filterTreatments
+      )
+  
+      andromeda$exitHistory <- andromeda$exitHistory %>%
+        dplyr::mutate(eventCohortId = as.character(as.integer(.data$eventCohortId)))
+      
       andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
-        dplyr::group_by(.data$personId) %>%
-        dplyr::mutate(eventSeq = dplyr::row_number())
-
-      andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
-        dplyr::filter(.data$eventSeq <= !!settings$maxPathLength)
-
-      # Add event_cohort_name (instead of only event_cohort_id)
-      addLabels(andromeda = andromeda)
-
-      # Order the combinations
-      eventCohortNames <- andromeda$treatmentHistory %>%
-        dplyr::select("eventCohortName") %>%
-        dplyr::pull() %>%
-        stringr::str_split(pattern = "\\+") %>%
-        lapply(FUN = function(x) {
-          paste(sort(x), collapse = "+")
-        }) %>%
-        unlist()
-
-      andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
-        dplyr::collect() %>%
-        dplyr::mutate(
-          eventCohortName = eventCohortNames,
-          indexYear = floor(.data$indexYear / 365.25) + 1970)
+        dplyr::union_all(andromeda$exitHistory)
+  
+      if (andromeda$treatmentHistory %>% dplyr::summarise(n = dplyr::n()) %>% pull() > 0) {
+        # Add eventSeq number to determine order of treatments in pathway
+        andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
+          dplyr::arrange(.data$personId, .data$eventStartDate, .data$eventEndDate)
+  
+        andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
+          dplyr::group_by(.data$personId) %>%
+          dplyr::mutate(eventSeq = dplyr::row_number())
+  
+        andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
+          dplyr::filter(.data$eventSeq <= !!settings$maxPathLength)
+  
+        # Add event_cohort_name (instead of only event_cohort_id)
+        addLabels(andromeda = andromeda)
+  
+        # Order the combinations
+        eventCohortNames <- andromeda$treatmentHistory %>%
+          dplyr::select("eventCohortName") %>%
+          dplyr::pull() %>%
+          stringr::str_split(pattern = "\\+") %>%
+          lapply(FUN = function(x) {
+            paste(sort(x), collapse = "+")
+          }) %>%
+          unlist()
+  
+        andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
+          dplyr::collect() %>%
+          dplyr::mutate(
+            eventCohortName = eventCohortNames,
+            indexYear = floor(.data$indexYear / 365.25) + 1970)
+      }
+    } else {
+      warning(sprintf("No cases found for: %s (%s). Generating empty treatmentHistory table.", targetCohortId, targetCohortName))
+    }
+  
+    if (is.null(andromeda$treatmentHistoryFinal)) {
+      andromeda$treatmentHistoryFinal <- andromeda$treatmentHistory %>%
+            dplyr::filter(!is.na(.data$personId))
+    } else {
+      andromeda$treatmentHistoryFinal <- andromeda$treatmentHistoryFinal %>%
+        dplyr::union_all(
+          andromeda$treatmentHistory %>%
+            dplyr::filter(!is.na(.data$personId))
+        )
     }
-  } else {
-    warning("No cases found. Generating empty treatmentHistory table.")
   }
-
-  andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
-    dplyr::filter(!is.na(.data$personId))
   return(andromeda)
 }
 
@@ -160,13 +176,13 @@ getCohortIds <- function(cohorts, cohortType) {
 #' }
 createTreatmentHistory <- function(
     andromeda,
-    targetCohortIds,
+    targetCohortId,
     eventCohortIds,
     exitCohortIds,
     indexDateOffset,
     includeTreatments) {
   andromeda$targetCohorts <- andromeda$cohortTable %>%
-    dplyr::filter(.data$cohortId %in% targetCohortIds) %>%
+    dplyr::filter(.data$cohortId %in% targetCohortId) %>%
     dplyr::mutate(type = "target") %>%
     dplyr::mutate(indexYear = as.numeric(format(.data$startDate, "%Y"))) %>%
     dplyr::mutate(indexDate = .data$startDate + indexDateOffset)
@@ -196,7 +212,7 @@ createTreatmentHistory <- function(
   # Only keep event cohorts starting (startDate) or ending (endDate) after
   # target cohort start date
   if (includeTreatments == "startDate") {
-    andromeda$cohortTable <- dplyr::full_join(
+    andromeda[[sprintf("cohortTable_%s", targetCohortId)]] <- dplyr::full_join(
       x = andromeda$eventCohorts,
       y = andromeda$targetCohorts,
       by = dplyr::join_by(
@@ -205,45 +221,46 @@ createTreatmentHistory <- function(
         y$indexDate <= x$startDate,
         x$startDate <= y$endDate,
         x$endDate <= y$endDate,
-      ))
+      ), suffix = c("Event", "Target"))
   } else if (includeTreatments == "endDate") {
-    andromeda$cohortTable <- dplyr::full_join(
+    andromeda[[sprintf("cohortTable_%s", targetCohortId)]] <- dplyr::full_join(
       x = andromeda$eventCohorts,
       y = andromeda$targetCohorts,
       by = dplyr::join_by(
         "personId",
         y$indexDate <= x$endDate,
         x$endDate <= y$endDate
-      )) %>%
+      ), suffix = c("Event", "Target")) %>%
       dplyr::mutate(
-        startDate.x = pmax(
-          .data$startDate.y + indexDateOffset,
-          .data$startDate.x,
+        startDateEvent = pmax(
+          .data$startDateTarget + indexDateOffset,
+          .data$startDateEvent,
           na.rm = TRUE
         )
       )
   }
-  
-  andromeda$treatmentHistory <- andromeda$cohortTable %>%
+
+  andromeda$treatmentHistory <- andromeda[[sprintf("cohortTable_%s", targetCohortId)]] %>%
     dplyr::select(
       "personId",
       "indexYear",
-      eventCohortId = "cohortId.x",
-      eventStartDate = "startDate.x",
-      eventEndDate = "endDate.x",
-      type = "type.x",
-      age = "age.x",
-      sex = "sex.x") %>%
+      eventCohortId = "cohortIdEvent",
+      eventStartDate = "startDateEvent",
+      eventEndDate = "endDateEvent",
+      type = "typeEvent",
+      age = "ageEvent",
+      sex = "sexEvent",
+      targetCohortId = "cohortIdTarget") %>%
     dplyr::mutate(
       durationEra = .data$eventEndDate - .data$eventStartDate,
       eventCohortId = as.character(floor(.data$eventCohortId))) %>%
     dplyr::filter(!is.na(.data$indexYear))
-  
+
   attrCounts <- fetchAttritionCounts(andromeda, "treatmentHistory")
   appendAttrition(
     toAdd = data.frame(
       number_records = attrCounts$nRecords,
-      number_subject = attrCounts$nSubjects,
+      number_subjects = attrCounts$nSubjects,
       reason_id = 3,
       reason = sprintf("Removing events where index date < target index date + indexDateOffset (%s)", indexDateOffset)
     ),
@@ -270,7 +287,6 @@ doSplitEventCohorts <- function(
     andromeda,
     splitEventCohorts,
     splitTime) {
-  
   if (!is.null(splitEventCohorts) & !is.null(splitTime)) {
     # Load in labels cohorts
     labels <- andromeda$cohorts %>%
@@ -307,12 +323,14 @@ doSplitEventCohorts <- function(
       
       andromeda$labels <- rbind(labels, acute, therapy)
     }
+  } else {
+    andromeda$labels <- andromeda$cohorts
   }
   attrCounts <- fetchAttritionCounts(andromeda, "treatmentHistory")
   appendAttrition(
     toAdd = data.frame(
       number_records = attrCounts$nRecords,
-      number_subject = attrCounts$nSubjects,
+      number_subjects = attrCounts$nSubjects,
       reason_id = 4,
       reason = sprintf("splitEventCohorts")
     ),
@@ -334,77 +352,43 @@ doSplitEventCohorts <- function(
 #' @return (`invisible(NULL)`)
 doEraCollapse <- function(andromeda, eraCollapseSize) {
   andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
-    dplyr::group_by(.data$personId, .data$eventCohortId) %>%
+    dplyr::group_by(.data$eventCohortId, .data$personId) %>%
     dplyr::mutate(
-      lagVariable = dplyr::lag(.data$eventEndDate, order_by = .data$eventStartDate)) %>%
+      prevStart = dplyr::lag(.data$eventStartDate),
+      prevEnd = dplyr::lag(.data$eventEndDate),
+      gap = as.numeric(.data$eventStartDate - .data$prevEnd)
+    ) %>%
     dplyr::ungroup() %>%
-    dplyr::mutate(
-      needsMerge = .data$eventStartDate - .data$lagVariable < eraCollapseSize,
-      rowNumber = dplyr::row_number()) %>%
-    dplyr::select(-"lagVariable")
+    dplyr::mutate(row = row_number()) %>%
+    dbplyr::window_order(.data$eventCohortId, .data$eventStartDate, .data$eventEndDate)
+
+  rows <- andromeda$treatmentHistory %>%
+    dplyr::filter(.data$gap <= eraCollapseSize) %>%
+    dplyr::pull(.data$row)
   
-  needsMerge <- andromeda$treatmentHistory %>%
-    dplyr::filter(.data$needsMerge) %>%
-    dplyr::select("rowNumber") %>%
-    dplyr::collect() %>%
-    dplyr::arrange(.data$rowNumber)
-  
-  n <- nrow(needsMerge)
-  
-  # Remove all rows with gap_same < eraCollapseSize
-  if (n == 0) {
-    andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
-      dplyr::select(-"needsMerge", -"rowNumber") %>%
-      dplyr::mutate(durationEra = .data$eventEndDate - .data$eventStartDate)
-  } else {
-    blockEnd <- as.numeric(needsMerge$rowNumber[seq_len(n)] != needsMerge$rowNumber[seq_len(n)]) + 1
-    needsMerge$blockId <- cumsum(blockEnd)
-    needsMerge <- needsMerge %>%
-      dplyr::group_by(.data$blockId) %>%
-      dplyr::summarise(
-        startRowNumber = min(rowNumber, na.rm = TRUE) - 1,
-        endRowNumber = max(rowNumber, na.rm = TRUE),
-        .groups = "drop")
-    
-    newEndDates <- andromeda$treatmentHistory %>%
-      dplyr::inner_join(
-        needsMerge,
-        copy = TRUE,
-        by = dplyr::join_by("rowNumber" == "endRowNumber")) %>% 
-      dplyr::select("startRowNumber", newEndDate = "eventEndDate")
+  for (row in rev(rows)) {
+    endDate <- andromeda$treatmentHistory %>%
+      dplyr::filter(dplyr::row_number() == !!row) %>%
+      dplyr::pull(.data$eventEndDate)
     
     andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
-      dplyr::left_join(
-        newEndDates,
-        by = dplyr::join_by("rowNumber" == "startRowNumber")) %>%
-      dplyr::mutate(
-        eventEndDate = dplyr::case_when(
-          !is.na(.data$newEndDate) ~ .data$newEndDate,
-          .default = .data$eventEndDate
-        ),
-        needsMerge = dplyr::case_when(
-          !is.na(.data$newEndDate) ~ NA,
-          .default = .data$needsMerge
-        )
-      ) %>% 
-      dplyr::mutate(durationEra = .data$eventEndDate - .data$eventStartDate) %>%
-      # dplyr::mutate(
-      #   eventEndDate = if_else(
-      #     is.null(.data$newEndDate), 
-      #     .data$eventEndDate, 
-      #     .data$newEndDate)) %>%
-      dplyr::filter(is.na(.data$needsMerge)) %>%
-      dplyr::select(-"newEndDate", -"needsMerge", -"rowNumber") %>%
-      dplyr::mutate(durationEra = .data$eventEndDate - .data$eventStartDate)
+      dplyr::mutate(eventEndDate = dplyr::case_when(
+        dplyr::row_number() == !!row - 1 ~ endDate,
+        .default = .data$eventEndDate
+      ))
   }
-  
+
+  andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
+    dplyr::filter(!dplyr::row_number() %in% rows) %>%
+    dplyr::select(-"prevStart", -"prevEnd", -"gap", -"row")
+
   attrCounts <- fetchAttritionCounts(andromeda, "treatmentHistory")
   appendAttrition(
     toAdd = data.frame(
       number_records = attrCounts$nRecords,
-      number_subject = attrCounts$nSubjects,
+      number_subjects = attrCounts$nSubjects,
       reason_id = 5,
-      reason = sprintf("eraCollapse (%s)", eraCollapseSize)
+      reason = sprintf("Collapsing eras, eraCollapse (%s)", eraCollapseSize)
     ),
     andromeda = andromeda
   )
@@ -602,7 +586,7 @@ doCombinationWindow <- function(
     appendAttrition(
       toAdd = data.frame(
         number_records = attrCounts$nRecords,
-        number_subject = attrCounts$nSubjects,
+        number_subjects = attrCounts$nSubjects,
         reason_id = 6,
         reason = sprintf("Iteration %s: minPostCombinationDuration (%s), combinatinoWindow (%s)", iterations, minPostCombinationDuration, combinationWindow)
       ),
@@ -611,12 +595,11 @@ doCombinationWindow <- function(
 
     andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
       dplyr::select(
-        "personId", "indexYear", "eventCohortId", "eventStartDate", "age",
+        "personId", "indexYear", "eventCohortId", "targetCohortId", "eventStartDate", "age",
         "sex", "eventEndDate", "durationEra", "gapPrevious"
       )
     
     selectRowsCombinationWindow(andromeda)
-    
     iterations <- iterations + 1
   }
   
@@ -624,7 +607,7 @@ doCombinationWindow <- function(
   appendAttrition(
     toAdd = data.frame(
       number_records = attrCounts$nRecords,
-      number_subject = attrCounts$nSubjects,
+      number_subjects = attrCounts$nSubjects,
       reason_id = 7,
       reason = sprintf("After Combination")
     ),
@@ -750,7 +733,7 @@ doFilterTreatments <- function(andromeda, filterTreatments) {
     
     # Remove all rows with same sequential treatments
     andromeda$treatmentHistory <- andromeda$treatmentHistory %>%
-      dplyr::group_by(.data$personId, .data$age, .data$sex, .data$indexYear, .data$eventCohortId, .data$group, .data$sortOrder) %>%
+      dplyr::group_by(.data$personId, .data$targetCohortId, .data$age, .data$sex, .data$indexYear, .data$eventCohortId, .data$group, .data$sortOrder) %>%
       dplyr::summarise(
         eventStartDate = min(.data$eventStartDate, na.rm = TRUE),
         eventEndDate = max(.data$eventEndDate, na.rm = TRUE),
@@ -764,7 +747,7 @@ doFilterTreatments <- function(andromeda, filterTreatments) {
   appendAttrition(
     toAdd = data.frame(
       number_records = attrCounts$nRecords,
-      number_subject = attrCounts$nSubjects,
+      number_subjects = attrCounts$nSubjects,
       reason_id = 8,
       reason = sprintf("filterTreatments (%s)", filterTreatments)
     ),
